@@ -5,6 +5,8 @@
 #'
 #' @param x data vector corresponding to that row / column (which will be the
 #'   same for diagonal 'panels').
+#' @param kernel the smoothing kernel to be used. See [stats::density()] for
+#'   options.
 #' @inheritParams stats::density
 #' @param ... Further arguments passed on to [lattice::diag.panel.splom()] and
 #'   [lattice::panel.lines()].
@@ -15,9 +17,10 @@
 #'
 #' @examples
 #' splom(~ iris[1:4],
-#'       data = iris,
-#'       diag.panel = diag.panel.splom.density,
-#'       pscales = 0)
+#'   data = iris,
+#'   diag.panel = diag.panel.splom.density,
+#'   pscales = 0
+#' )
 diag.panel.splom.density <- function(x,
                                      bw = "nrd0",
                                      adjust = 1,
@@ -27,11 +30,12 @@ diag.panel.splom.density <- function(x,
                                      ...) {
   yrng <- current.panel.limits()$ylim
   d <- density(x,
-               bw = bw,
-               adjust = adjust,
-               kernel = kernel,
-               weights = weights,
-               n = n, na.rm = TRUE)
+    bw = bw,
+    adjust = adjust,
+    kernel = kernel,
+    weights = weights,
+    n = n, na.rm = TRUE
+  )
   d$y <- yrng[1] + 0.95 * diff(yrng) * d$y / max(d$y, na.rm = TRUE)
   panel.lines(d, ...)
   diag.panel.splom(x, ...) # for labels
